BeiZiNativeAd class
原生广告类
Constructors
- BeiZiNativeAd({required String adSpaceId, required int totalTime, required BeiZiNativeAdListener? listener, int? modelType, String? spaceParam})
Properties
- adHeight ↔ double?
-
getter/setter pair
- adSpaceId → String
-
final
- adWidth ↔ double?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- listener ↔ BeiZiNativeAdListener?
-
getter/setter pair
- mCloseWidgetCall ↔ AdWidgetNeedCloseCall?
-
getter/setter pair
- modelType → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spaceParam → String?
-
final
- totalTime → int
-
final
Methods
-
destroy(
) → void - InterstitialAd.cancel
-
getCustomExtraData(
) → Future - 开发者根据不同平台进行处理 Android 返回 String?类型 IOS 返回 Map? 类型
-
getCustomExtraJsonData(
) → Future< String?> -
getCustomParam(
) → Future - 开发者根据不同平台进行处理 只有 IOS 返回 Map? 类型 ,Android 返回 null类型
-
getECPM(
) → Future< int> - 单位:人民币(分)
-
loadAd(
{required double width, required double height}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → void - 广告pause
-
resume(
) → void - 广告resume
-
sendLossNotificationWithInfo(
Map< String, String> lossInfo) → Future<void> - 注意:必须为有效的字符串格式的键值对!!!!! @param lossInfo 竞败信息 BeiZiBiddingConstant.KEY_WIN_PRICE :竞胜价格 (单位: 分; 整数),必填(value值使用字符串即可) BeiZiBiddingConstant.KEY_ADN_ID :竞胜渠道ID,必填(value值使用BeiZiBiddingConstant.Adn类下的常量字符串即可) BeiZiBiddingConstant.KEY_LOSS_REASON :失败原因,必填(value值使用BeiZiBiddingConstant.LossReason类下的常量字符串即可)
-
sendWinNotificationWithInfo(
Map< String, String> winInfo) → Future<void> - 注意:必须为有效的字符串格式的键值对!!!!! @param winInfo 竞胜信息 BeiZiBiddingConstant.KEY_WIN_PRICE :竞胜价格 (单位: 分; 整数),必填(value值使用字符串即可) BeiZiBiddingConstant.KEY_ADN_ID :失败渠道中最高价格渠道ID,必填(value值使用BeiZiBiddingConstant.Adn类下的常量字符串即可) BeiZiBiddingConstant.KEY_HIGHEST_LOSS_PRICE :失败渠道中最高价格,必填(value值使用字符串即可)
-
setAdCloseCallBack(
AdWidgetNeedCloseCall? closeWidgetCall) → void -
setBidResponse(
String content) → void -
setSpaceParam(
Map< String, Object> map) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited