AppDetail class

应用下载六要素

Constructors

AppDetail()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

appDescription → const String
应用描述的存储键
appDeveloper → const String
应用开发者的存储键
appName → const String
应用名称的存储键
appPermissionInfo → const String
应用权限信息的存储键
appPrivacyPolicy → const String
应用隐私政策的存储键
appVersion → const String
应用版本的存储键